<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name></name>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt;Peter Mattern &lt;a href=&quot;mailto:pmattern@arcor.de&quot;&gt;pmattern@arcor.de&lt;/a&gt;&lt;br/&gt; [de] German translation, Project</source>
        <translation>&lt;p&gt;Peter Mattern &lt;a href=&quot;mailto:pmattern@arcor.de&quot;&gt;pmattern@arcor.de&lt;/a&gt;&lt;br/&gt; [de] German translation, Project</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt;Dimitrios Glentadakis &lt;a href=&quot;mailto:dglent@free.fr&quot;&gt;dglent@free.fr&lt;/a&gt;&lt;br/&gt; [el] Greek translation</source>
        <translation>&lt;p&gt;Dimitrios Glentadakis &lt;a href=&quot;mailto:dglent@free.fr&quot;&gt;dglent@free.fr&lt;/a&gt;&lt;br/&gt; [el] Greek translation</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt;Ozkar L. Garcell &lt;a href=&quot;mailto:ozkar.garcell@gmail.com&quot;&gt;ozkar.garcell@gmail.com&lt;/a&gt;&lt;br/&gt; [es] Spanish translation</source>
        <translation type="obsolete">&lt;p&gt;Ozkar L. Garcell &lt;a href=&quot;mailto:ozkar.garcell@gmail.com&quot;&gt;ozkar.garcell@gmail.com&lt;/a&gt;&lt;br/&gt; [es] Spanish translation</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt;Laurene Albrand &lt;a href=&quot;mailto:laurenealbrand@outlook.com&quot;&gt;laurenealbrand@outlook.com&lt;/a&gt;&lt;br/&gt; [fr] French translation</source>
        <translation>&lt;p&gt;Laurene Albrand &lt;a href=&quot;mailto:laurenealbrand@outlook.com&quot;&gt;laurenealbrand@outlook.com&lt;/a&gt;&lt;br/&gt; [fr] French translation</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt;Rémi Verschelde &lt;a href=&quot;mailto:remi@verschelde.fr&quot;&gt;remi@verschelde.fr&lt;/a&gt;&lt;br/&gt; [fr] French translation, Project</source>
        <translation>&lt;p&gt;Rémi Verschelde &lt;a href=&quot;mailto:remi@verschelde.fr&quot;&gt;remi@verschelde.fr&lt;/a&gt;&lt;br/&gt; [fr] French translation, Project</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt;Daniel Napora &lt;a href=&quot;mailto:napcok@gmail.com&quot;&gt;napcok@gmail.com&lt;/a&gt;&lt;br/&gt; Tomasz Przybył &lt;a href=&quot;mailto:fademind@gmail.com&quot;&gt;fademind@gmail.com&lt;/a&gt;&lt;br/&gt; [pl] Polish translation</source>
        <translation>&lt;p&gt;Daniel Napora &lt;a href=&quot;mailto:napcok@gmail.com&quot;&gt;napcok@gmail.com&lt;/a&gt;&lt;br/&gt; Tomasz Przybył &lt;a href=&quot;mailto:fademind@gmail.com&quot;&gt;fademind@gmail.com&lt;/a&gt;&lt;br/&gt; [pl] Polish translation</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt;Atilla Öntaş &lt;a href=&quot;mailto:tarakbumba@gmail.com&quot;&gt;tarakbumba@gmail.com&lt;/a&gt;&lt;br/&gt; [tr] Turkish translation</source>
        <translation>&lt;p&gt;Atilla Öntaş &lt;a href=&quot;mailto:tarakbumba@gmail.com&quot;&gt;tarakbumba@gmail.com&lt;/a&gt;&lt;br/&gt; [tr] Turkish translation</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt;Yuri Chornoivan &lt;a href=&quot;mailto:yurchor@ukr.net&quot;&gt;yurchor@ukr.net&lt;/a&gt;&lt;br/&gt; [uk] Ukrainian translation</source>
        <translation>&lt;p&gt;Yuri Chornoivan &lt;a href=&quot;mailto:yurchor@ukr.net&quot;&gt;yurchor@ukr.net&lt;/a&gt;&lt;br/&gt; [uk] Ukrainian translation</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt;You-Cheng Hsieh &lt;a href=&quot;mailto:yochenhsieh@gmail.com&quot;&gt;yochenhsieh@gmail.com&lt;/a&gt;&lt;br/&gt; [zh_TW] Chinese (Taiwan) translation</source>
        <translation>&lt;p&gt;You-Cheng Hsieh &lt;a href=&quot;mailto:yochenhsieh@gmail.com&quot;&gt;yochenhsieh@gmail.com&lt;/a&gt;&lt;br/&gt; [zh_TW] Chinese (Taiwan) translation</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt;pmav99&lt;br/&gt; Project</source>
        <translation>&lt;p&gt;pmav99&lt;br/&gt; Project</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt;Heimen Stoffels &lt;a href=&quot;mailto:vistausss@outlook.com&quot;&gt;vistausss@outlook.com&lt;/a&gt;&lt;br/&gt; [nl] Dutch translation</source>
        <translation>&lt;p&gt;Heimen Stoffels &lt;a href=&quot;mailto:vistausss@outlook.com&quot;&gt;vistausss@outlook.com&lt;/a&gt;&lt;br/&gt; [nl] Dutch translation</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt;werthad &lt;a href=&quot;mailto:werthad@gmail.com&quot;&gt;werthad@gmail.com&lt;/a&gt;&lt;br/&gt; [hu] Hungarian translation</source>
        <translation>&lt;p&gt;werthad &lt;a href=&quot;mailto:werthad@gmail.com&quot;&gt;werthad@gmail.com&lt;/a&gt;&lt;br/&gt; [hu] Hungarian translation</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt;Artem Vorotnikov &lt;a href=&quot;mailto:artem@vorotnikov.me&quot;&gt;artem@vorotnikov.me&lt;/a&gt;&lt;br/&gt; Sergey Shitikov &lt;a href=&quot;mailto:rw4lll@yandex.ru&quot;&gt;rw4lll@yandex.ru&lt;/a&gt;&lt;br/&gt;Alexey Zakaldaev &lt;a href=&quot;mailto:nelex111@gmail.com&quot;&gt;nelex111@gmail.com&lt;/a&gt;&lt;br/&gt;Liliya Panova&lt;br/&gt; [ru] Russian translation</source>
        <translation>&lt;p&gt;Artem Vorotnikov &lt;a href=&quot;mailto:artem@vorotnikov.me&quot;&gt;artem@vorotnikov.me&lt;/a&gt;&lt;br/&gt; Sergey Shitikov &lt;a href=&quot;mailto:rw4lll@yandex.ru&quot;&gt;rw4lll@yandex.ru&lt;/a&gt;&lt;br/&gt;Alexey Zakaldaev &lt;a href=&quot;mailto:nelex111@gmail.com&quot;&gt;nelex111@gmail.com&lt;/a&gt;&lt;br/&gt;Liliya Panova&lt;br/&gt; [ru] Russian translation</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt; juancarlospaco &lt;a href=&quot;mailto:JuanCarlosPaco@gmail.com&quot;&gt;JuanCarlosPaco@gmail.com&lt;/a&gt;&lt;br/&gt; [es] Spanish translation, Project</source>
        <translation>&lt;p&gt; juancarlospaco &lt;a href=&quot;mailto:JuanCarlosPaco@gmail.com&quot;&gt;JuanCarlosPaco@gmail.com&lt;/a&gt;&lt;br/&gt; [es] Spanish translation, Project</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt;jose1711 &lt;a href=&quot;mailto:jose1711@gmail.com&quot;&gt;jose1711@gmail.com&lt;/a&gt;&lt;br&gt; [sk] Slovak translation, Project</source>
        <translation>&lt;p&gt;jose1711 &lt;a href=&quot;mailto:jose1711@gmail.com&quot;&gt;jose1711@gmail.com&lt;/a&gt;&lt;br&gt; [sk] Slovak translation, Project</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt;Archita Zabaleta &lt;a href=&quot;mailto:architazabaleta@gmail.com&quot;&gt;architazabaleta@gmail.com&lt;/a&gt;&lt;br/&gt; [it] Italian translation</source>
        <translation>&lt;p&gt;Archita Zabaleta &lt;a href=&quot;mailto:architazabaleta@gmail.com&quot;&gt;architazabaleta@gmail.com&lt;/a&gt;&lt;br/&gt; [it] Italian translation</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>Jiri Podhorecky&lt;br/&gt;Pavel Fric&lt;br/&gt;[cs] Czech translation</source>
        <translation>Jiri Podhorecky&lt;br/&gt;Pavel Fric&lt;br/&gt;[cs] Czech translation</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt;Jürgen Thurau &lt;a href=&quot;mailto:linux@psyca.de&quot;&gt;linux@psyca.de&lt;/a&gt;&lt;br/&gt;[de] German translation</source>
        <translation>&lt;p&gt;Jürgen Thurau &lt;a href=&quot;mailto:linux@psyca.de&quot;&gt;linux@psyca.de&lt;/a&gt;&lt;br/&gt;[de] German translation</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt;Masamichi Ito &lt;a href=&quot;https://github.com/ito32bit&quot;&gt;https://github.com/ito32bit&lt;/a&gt;&lt;br/&gt; [ja] Japanese translation</source>
        <translation>&lt;p&gt;Masamichi Ito &lt;a href=&quot;https://github.com/ito32bit&quot;&gt;https://github.com/ito32bit&lt;/a&gt;&lt;br/&gt; [ja] Japanese translation</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt;Adrian Moise&lt;a href=&quot;mailto:sah.mat.ro@gmail.com&quot;&gt;sah.mat.ro@gmail.com&lt;/a&gt;&lt;br/&gt; [ro] Romanian translation</source>
        <translation>&lt;p&gt;Adrian Moise&lt;a href=&quot;mailto:sah.mat.ro@gmail.com&quot;&gt;sah.mat.ro@gmail.com&lt;/a&gt;&lt;br/&gt; [ro] Romanian translation</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt;Ozkar L. Garcell &lt;a href=&quot;mailto:ozkar.garcell@gmail.com&quot;&gt;ozkar.garcell@gmail.com&lt;/a&gt;&lt;br/&gt; Teo Laírla (teolairlasg) &lt;a href=&quot;mailto:teo.lairla@iessierradeguara.com&quot;&gt;teo.lairla@iessierradeguara.com&lt;/a&gt;&lt;br/&gt; [es] Spanish translation</source>
        <translation>&lt;p&gt;Ozkar L. Garcell &lt;a href=&quot;mailto:ozkar.garcell@gmail.com&quot;&gt;ozkar.garcell@gmail.com&lt;/a&gt;&lt;br/&gt; Teo Laírla (teolairlasg) &lt;a href=&quot;mailto:teo.lairla@iessierradeguara.com&quot;&gt;teo.lairla@iessierradeguara.com&lt;/a&gt;&lt;br/&gt; [es] Spanish translation</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="50"/>
        <source>&lt;p&gt;standreas &lt;a href=&quot;mailto:standreas@riseup.net&quot;&gt;standreas@riseup.net&lt;/a&gt;&lt;br/&gt; [it] Italian translation, Weblate</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../about_dlg.py" line="23"/>
        <source>About</source>
        <translation>关于</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="24"/>
        <source>Contributors</source>
        <translation>合作者</translation>
    </message>
    <message>
        <location filename="../about_dlg.py" line="46"/>
        <source>About Meteo-qt</source>
        <translation>关于Meteo-qt</translation>
    </message>
</context>
<context>
    <name>Action to open the dialog with the weather alerts</name>
    <message>
        <location filename="../meteo_qt.py" line="149"/>
        <source>&amp;Alerts</source>
        <comment>Systray icon context menu</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Action to refresh the weather infos from the server</name>
    <message>
        <location filename="../meteo_qt.py" line="141"/>
        <source>&amp;Refresh</source>
        <comment>Systray icon context menu</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Air Quality Index 1</name>
    <message>
        <location filename="../meteo_qt.py" line="488"/>
        <source>Good</source>
        <comment>The value in the weather info dialogue</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Air Quality Index 2</name>
    <message>
        <location filename="../meteo_qt.py" line="493"/>
        <source>Fair</source>
        <comment>The value in the weather info dialogue</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Air Quality Index 3</name>
    <message>
        <location filename="../meteo_qt.py" line="498"/>
        <source>Moderate</source>
        <comment>The value in the weather info dialogue</comment>
        <translation type="unfinished">中</translation>
    </message>
</context>
<context>
    <name>Air Quality Index 4</name>
    <message>
        <location filename="../meteo_qt.py" line="503"/>
        <source>Poor</source>
        <comment>The value in the weather info dialogue</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Air Quality Index 5</name>
    <message>
        <location filename="../meteo_qt.py" line="508"/>
        <source>Very Poor</source>
        <comment>The value in the weather info dialogue</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Beaufort scale 0 - https://en.wikipedia.org/wiki/Beaufort_scale#Modern_scale</name>
    <message>
        <location filename="../conditions.py" line="192"/>
        <source>Sea: Sea like a mirror
Land: Calm. Smoke rises vertically</source>
        <comment>Tooltip in Weather overview dialogue</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Beaufort scale 1 - https://en.wikipedia.org/wiki/Beaufort_scale#Modern_scale</name>
    <message>
        <location filename="../conditions.py" line="197"/>
        <source>Sea: Ripples with the appearance of scales are formed,but without foam crests
Land: Smoke drift indicates wind direction. Leaves and wind vanes are stationary</source>
        <comment>Tooltip in Weather overview dialogue</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Beaufort scale 10 - https://en.wikipedia.org/wiki/Beaufort_scale#Modern_scale</name>
    <message>
        <location filename="../conditions.py" line="267"/>
        <source>Sea: Very high waves with overhanging crests. Large patches of foam from wave crests give the sea a white appearance. Considerable tumbling of waves with heavy impact. Large amounts of airborne spray reduce visibility
Land: Trees are broken off or uprooted, structural damage likely</source>
        <comment>Tooltip in Weather overview dialogue</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Beaufort scale 11 - https://en.wikipedia.org/wiki/Beaufort_scale#Modern_scale</name>
    <message>
        <location filename="../conditions.py" line="277"/>
        <source>Sea: Exceptionally high waves. Very large patches of foam, driven before the wind, cover much of the sea surface. Very large amounts of airborne spray severely reduce visibility
Land: Widespread vegetation and structural damage likely</source>
        <comment>Tooltip in Weather overview dialogue</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Beaufort scale 12 - https://en.wikipedia.org/wiki/Beaufort_scale#Modern_scale</name>
    <message>
        <location filename="../conditions.py" line="285"/>
        <source>Sea: Huge waves. Sea is completely white with foam and spray. Air is filled with driving spray, greatly reducing visibility
Land: Severe widespread damage to vegetation and structures. Debris and unsecured objects are hurled about</source>
        <comment>Tooltip in Weather overview dialogue</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Beaufort scale 2 - https://en.wikipedia.org/wiki/Beaufort_scale#Modern_scale</name>
    <message>
        <location filename="../conditions.py" line="204"/>
        <source>Sea: Small wavelets, still short but more pronounced; crests have a glassy appearance and do not break
Land: Wind felt on exposed skin. Leaves rustle. Wind vanes begin to move</source>
        <comment>Tooltip in Weather overview dialogue</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Beaufort scale 3 - https://en.wikipedia.org/wiki/Beaufort_scale#Modern_scale</name>
    <message>
        <location filename="../conditions.py" line="212"/>
        <source>Sea: Large wavelets. Crests begin to break; scattered whitecaps
Land: Leaves and small twigs constantly moving, light flags extended</source>
        <comment>Tooltip in Weather overview dialogue</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Beaufort scale 4 - https://en.wikipedia.org/wiki/Beaufort_scale#Modern_scale</name>
    <message>
        <location filename="../conditions.py" line="219"/>
        <source>Sea: Small waves with breaking crests. Fairly frequent whitecaps
Land: Dust and loose paper raised. Small branches begin to move</source>
        <comment>Tooltip in Weather overview dialogue</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Beaufort scale 5 - https://en.wikipedia.org/wiki/Beaufort_scale#Modern_scale</name>
    <message>
        <location filename="../conditions.py" line="226"/>
        <source>Sea: Moderate waves of some length. Many whitecaps. Small amounts of spray
Land: Branches of a moderate size move. Small trees in leaf begin to sway</source>
        <comment>Tooltip in Weather overview dialogue</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Beaufort scale 6 - https://en.wikipedia.org/wiki/Beaufort_scale#Modern_scale</name>
    <message>
        <location filename="../conditions.py" line="233"/>
        <source>Sea: Long waves begin to form. White foam crests are very frequent. Some airborne spray is present
Land: Large branches in motion. Whistling heard in overhead wires. Umbrella use becomes difficult. Empty plastic bins tip over</source>
        <comment>Tooltip in Weather overview dialogue</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Beaufort scale 7 - https://en.wikipedia.org/wiki/Beaufort_scale#Modern_scale</name>
    <message>
        <location filename="../conditions.py" line="241"/>
        <source>Sea: Sea heaps up. Some foam from breaking waves is blown into streaks along wind direction. Moderate amounts of airborne spray
Land: Whole trees in motion. Effort neededto walk against the wind</source>
        <comment>Tooltip in Weather overview dialogue</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Beaufort scale 8 - https://en.wikipedia.org/wiki/Beaufort_scale#Modern_scale</name>
    <message>
        <location filename="../conditions.py" line="249"/>
        <source>Sea: Moderately high waves with breaking crests forming spindrift. Well-marked streaks of foam are blown along wind direction. Considerable airborne spray
Land: Some twigs broken from trees. Cars veer on road. Progress on foot is seriously impeded</source>
        <comment>Tooltip in Weather overview dialogue</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Beaufort scale 9 - https://en.wikipedia.org/wiki/Beaufort_scale#Modern_scale</name>
    <message>
        <location filename="../conditions.py" line="258"/>
        <source>Sea: High waves whose crests sometimes roll over. Dense foam is blown along wind direction. Large amounts of airborne spray may begin to reduce visibility
Land: Some branches break off trees, and some small trees blow over. Construction/temporary signs and barricades blow over</source>
        <comment>Tooltip in Weather overview dialogue</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <location filename="../citylistdlg.py" line="53"/>
        <source>&amp;Translate</source>
        <comment>Edit cities name</comment>
        <translation>&amp;翻译</translation>
    </message>
</context>
<context>
    <name>Checkable option to show or not the window at startup</name>
    <message>
        <location filename="../settings.py" line="475"/>
        <source>Start minimized</source>
        <comment>Settings dialogue</comment>
        <translation>最小化启动</translation>
    </message>
</context>
<context>
    <name>Checkbox</name>
    <message>
        <location filename="../proxydlg.py" line="49"/>
        <source>Use proxy authentification</source>
        <comment>Proxy settings dialogue</comment>
        <translation>使用代理身份验证</translation>
    </message>
    <message>
        <location filename="../settings.py" line="425"/>
        <source>Connection by proxy</source>
        <comment>Settings dialogue</comment>
        <translation>通过代理连接</translation>
    </message>
</context>
<context>
    <name>CityListDlg</name>
    <message>
        <location filename="../citylistdlg.py" line="44"/>
        <source>&amp;Add...</source>
        <translation>&amp;添加...</translation>
    </message>
    <message>
        <location filename="../citylistdlg.py" line="44"/>
        <source>&amp;Remove...</source>
        <translation>&amp;移除...</translation>
    </message>
    <message>
        <location filename="../citylistdlg.py" line="44"/>
        <source>&amp;Up</source>
        <translation>&amp;向上</translation>
    </message>
    <message>
        <location filename="../citylistdlg.py" line="44"/>
        <source>&amp;Down</source>
        <translation>&amp;向下</translation>
    </message>
    <message>
        <location filename="../citylistdlg.py" line="44"/>
        <source>De&amp;fault</source>
        <translation>默&amp;认</translation>
    </message>
    <message>
        <location filename="../citylistdlg.py" line="44"/>
        <source>&amp;Sort</source>
        <translation>&amp;分类</translation>
    </message>
    <message>
        <location filename="../citylistdlg.py" line="139"/>
        <source>The city &quot;{0}&quot; has been removed</source>
        <translation>这个城市 &quot;{0}&quot;已被移除</translation>
    </message>
</context>
<context>
    <name>Comfort level</name>
    <message>
        <location filename="../meteo_qt.py" line="419"/>
        <source>Comfort</source>
        <comment>Weather overview dialogue</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Comfort level depending on the dew point</name>
    <message>
        <location filename="../humidex.py" line="32"/>
        <source>Dry</source>
        <comment>Weather info dialogue</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../humidex.py" line="46"/>
        <source>Very comfortable</source>
        <comment>Weather info dialogue</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../humidex.py" line="59"/>
        <source>Comfortable</source>
        <comment>Weather info dialogue</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../humidex.py" line="72"/>
        <source>Alright</source>
        <comment>Weather info dialogue</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../humidex.py" line="85"/>
        <source>Uncomfortable</source>
        <comment>Weather info dialogue</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../humidex.py" line="99"/>
        <source>Very uncomfortable</source>
        <comment>Weather info dialogue</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../humidex.py" line="112"/>
        <source>Severely uncomfortable</source>
        <comment>Weather info dialogue</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Comment about the comfort level depending on the dew point</name>
    <message>
        <location filename="../humidex.py" line="46"/>
        <source>Comfort level excellent for exercise</source>
        <comment>ToolTip in weather info dialogue</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../humidex.py" line="59"/>
        <source>Hard efforts likely not affected</source>
        <comment>ToolTip weather info dialogue</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../humidex.py" line="72"/>
        <source>Expect race times to be slower than in optimal conditions</source>
        <comment>ToolTip weather info dialogue</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../humidex.py" line="85"/>
        <source>Easy training runs might feel OK but difficult to race well or do hard efforts</source>
        <comment>ToolTip weather info dialogue</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../humidex.py" line="99"/>
        <source>Expect pace to suffer greatly</source>
        <comment>ToolTip weather info dialogue</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../humidex.py" line="112"/>
        <source>Avoid the exercise. Skip it or dramatically alter goal.
The comfort level is severely uncomfortable and possibly deadly for asthma sufferers</source>
        <comment>ToolTip in weather info dialogue</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../humidex.py" line="32"/>
        <source>The drier air can cause skin to crack and become irritated more easily</source>
        <comment>ToolTip in weather info dialogue</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Daylight duration</name>
    <message>
        <location filename="../meteo_qt.py" line="461"/>
        <source>Daylight</source>
        <comment>Weather overview dialogue</comment>
        <translation>阳光</translation>
    </message>
</context>
<context>
    <name>Dew point label</name>
    <message>
        <location filename="../meteo_qt.py" line="408"/>
        <source>Dew point</source>
        <comment>Weather overview dialogue</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Entry label for the proxy port</name>
    <message>
        <location filename="../proxydlg.py" line="39"/>
        <source>Port:</source>
        <comment>Proxy settings dialogue</comment>
        <translation>端口:</translation>
    </message>
</context>
<context>
    <name>Entry label for the proxy url</name>
    <message>
        <location filename="../proxydlg.py" line="27"/>
        <source>Proxy URL:</source>
        <comment>Proxy settings dialogue</comment>
        <translation>代理地址:</translation>
    </message>
</context>
<context>
    <name>Extreme UV recommended protection</name>
    <message>
        <location filename="../conditions.py" line="182"/>
        <source>Take all precautions: Wear SPF 30+ sunscreen, a long-sleeved
                shirt and trousers,&lt;br/&gt;sunglasses, and a very broad hat.
                Avoid the sun within three hours of solar noon.</source>
        <comment>Extreme https://en.wikipedia.org/wiki/Ultraviolet_index</comment>
        <translation>采取一切预防措施：穿SPF 30防晒霜，长袖 
衬衫和裤子&lt;br/&gt;太阳镜，宽帽子
太阳正午三小时内避免阳光照射。</translation>
    </message>
</context>
<context>
    <name>From the site: Why hPa Is Used - http://n-a-c.biz/WS62694/hPa.htm</name>
    <message>
        <location filename="../conditions.py" line="295"/>
        <source>If the barometric pressure is rising, the weather is improving.
If the barometric pressure is falling, the weather is worsening.
Above 1020 hPa is calm weather/cooler temperatures and below that is unsettled weather/warmer temperatures.
1010-1020 hPa would be weak to normal storms.
990-1010 hPa would be bad storms with possible hurricanes, tornadoes, and typhoons.
Below 990 hPa is the pressure for VERY BAD and POWERFUL hurricanes, tornadoes, and typhoons.</source>
        <comment>Tooltip for the pressure label in weather overview</comment>
        <translation>如果气压上升，天气就会好转
如果气压下降，天气就会恶化
1020 hPa以上是平静的天气/较冷的温度，低于天气/温度不稳定的温度
1010-1020 hPa对正常风暴很弱
990-1010 hPa将是可能遭受飓风，龙卷风和台风的恶劣风暴
低于990 hPa是非常恶劣和强大的飓风，龙卷风和台风的压力。</translation>
    </message>
</context>
<context>
    <name>High UV recommended protection</name>
    <message>
        <location filename="../conditions.py" line="171"/>
        <source>Cover the body with sun protective clothing, use SPF 30+
                sunscreen,&lt;br/&gt;wear a hat, reduce time in the sun within three
                hours of solar noon, and wear sunglasses.</source>
        <comment>High https://en.wikipedia.org/wiki/Ultraviolet_index</comment>
        <translation>用防晒衣遮住身体，使用防晒指数30防晒霜，
                &lt;br/&gt;戴上帽子，在太阳中午三小时内减少晒太阳的时间，
                并戴上太阳镜。</translation>
    </message>
</context>
<context>
    <name>If the temperature will be shown with a decimal or rounded in tray icon</name>
    <message>
        <location filename="../settings.py" line="167"/>
        <source>Temperature accuracy in system tray</source>
        <comment>Settings dialogue</comment>
        <translation>系统托盘的温度精度</translation>
    </message>
</context>
<context>
    <name>Label before the wind description</name>
    <message>
        <location filename="../meteo_qt.py" line="349"/>
        <source>Wind</source>
        <comment>Weather info panel</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Label for air quality index (air pollution)</name>
    <message>
        <location filename="../meteo_qt.py" line="473"/>
        <source>Air quality</source>
        <comment>Label in weather info dialogue</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Label for the cloudiness (%)</name>
    <message>
        <location filename="../meteo_qt.py" line="364"/>
        <source>Cloudiness</source>
        <comment>Weather info panel</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Label for the humidity (%)</name>
    <message>
        <location filename="../meteo_qt.py" line="386"/>
        <source>Humidity</source>
        <comment>Weather info panel</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Label for the pressure (hPa)</name>
    <message>
        <location filename="../meteo_qt.py" line="375"/>
        <source>Pressure</source>
        <comment>Weather info panel</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Label for the sunrise time (hh:mm)</name>
    <message>
        <location filename="../meteo_qt.py" line="441"/>
        <source>Sunrise</source>
        <comment>Weather info panel</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Label for the sunset (hh:mm)</name>
    <message>
        <location filename="../meteo_qt.py" line="450"/>
        <source>Sunset</source>
        <comment>Weather info panel</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Label of button to open the proxy dialogue</name>
    <message>
        <location filename="../settings.py" line="438"/>
        <source>Settings</source>
        <comment>Settings dialogue</comment>
        <translation>设置</translation>
    </message>
</context>
<context>
    <name>Label of the checkbox</name>
    <message>
        <location filename="../settings.py" line="127"/>
        <source>Wind speed unit</source>
        <comment>Settings dialogue</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Link to create a profile in OpenWeatherMap</name>
    <message>
        <location filename="../settings.py" line="455"/>
        <source>&lt;a href=&quot;http://home.openweathermap.org/users/sign_up&quot;&gt;Create key&lt;/a&gt;</source>
        <comment>Settings dialogue</comment>
        <translation>&lt;a href=&quot;http://home.openweathermap.org/users/sign_up&quot;&gt;创建密钥&lt;/a&gt;</translation>
    </message>
</context>
<context>
    <name>Low UV recommended protection</name>
    <message>
        <location filename="../conditions.py" line="159"/>
        <source>Wear sunglasses on bright days; use sunscreen if there is
                snow on&lt;br/&gt;the ground, which reflects UV radiation,
                or if you have particularly fair skin.</source>
        <comment>Low https://en.wikipedia.org/wiki/Ultraviolet_index</comment>
        <translation>明亮的日子戴上太阳镜;如果&lt;br/&gt;地面有雪，反射紫外线，
                 或者你的皮肤特别白皙，请使用防晒霜。</translation>
    </message>
</context>
<context>
    <name>Message when trying to remove thelast and unique city in the list</name>
    <message>
        <location filename="../citylistdlg.py" line="126"/>
        <source>This is the default city!</source>
        <comment>Cities list dialogue</comment>
        <translation>这是默认城市</translation>
    </message>
</context>
<context>
    <name>MeteoSettings</name>
    <message>
        <location filename="../settings.py" line="50"/>
        <source>City</source>
        <translation>城市</translation>
    </message>
    <message>
        <location filename="../settings.py" line="53"/>
        <source>Click to edit the cities list</source>
        <translation>点击以编辑城市列表</translation>
    </message>
    <message>
        <location filename="../settings.py" line="56"/>
        <source>Language</source>
        <translation>Language语言</translation>
    </message>
    <message>
        <location filename="../settings.py" line="66"/>
        <source>Bulgarian</source>
        <translation>Bulgarian</translation>
    </message>
    <message>
        <location filename="../settings.py" line="67"/>
        <source>Catalan</source>
        <translation>Catalan</translation>
    </message>
    <message>
        <location filename="../settings.py" line="68"/>
        <source>Czech</source>
        <translation>Czech</translation>
    </message>
    <message>
        <location filename="../settings.py" line="69"/>
        <source>Danish</source>
        <translation>Danish</translation>
    </message>
    <message>
        <location filename="../settings.py" line="70"/>
        <source>German</source>
        <translation>German</translation>
    </message>
    <message>
        <location filename="../settings.py" line="71"/>
        <source>Greek</source>
        <translation>Greek</translation>
    </message>
    <message>
        <location filename="../settings.py" line="72"/>
        <source>English</source>
        <translation>English</translation>
    </message>
    <message>
        <location filename="../settings.py" line="73"/>
        <source>Spanish</source>
        <translation>Spanish</translation>
    </message>
    <message>
        <location filename="../settings.py" line="74"/>
        <source>Finnish</source>
        <translation>Finnish</translation>
    </message>
    <message>
        <location filename="../settings.py" line="75"/>
        <source>French</source>
        <translation>French</translation>
    </message>
    <message>
        <location filename="../settings.py" line="76"/>
        <source>Hebrew</source>
        <translation>Hebrew</translation>
    </message>
    <message>
        <location filename="../settings.py" line="77"/>
        <source>Croatian</source>
        <translation>Croatian</translation>
    </message>
    <message>
        <location filename="../settings.py" line="78"/>
        <source>Hungarian</source>
        <translation>Hungarian</translation>
    </message>
    <message>
        <location filename="../settings.py" line="79"/>
        <source>Italian</source>
        <translation>Italian</translation>
    </message>
    <message>
        <location filename="../settings.py" line="80"/>
        <source>Japanese</source>
        <translation>Japanese</translation>
    </message>
    <message>
        <location filename="../settings.py" line="81"/>
        <source>Lithuanian</source>
        <translation>Lithuanian</translation>
    </message>
    <message>
        <location filename="../settings.py" line="82"/>
        <source>Norwegian (Bokmaal)</source>
        <translation>Norwegian (Bokmaal)</translation>
    </message>
    <message>
        <location filename="../settings.py" line="83"/>
        <source>Dutch</source>
        <translation>Dutch</translation>
    </message>
    <message>
        <location filename="../settings.py" line="84"/>
        <source>Polish</source>
        <translation>Polish</translation>
    </message>
    <message>
        <location filename="../settings.py" line="85"/>
        <source>Portuguese</source>
        <translation>Portuguese</translation>
    </message>
    <message>
        <location filename="../settings.py" line="86"/>
        <source>Brazil Portuguese</source>
        <translation>Brazil Portuguese</translation>
    </message>
    <message>
        <location filename="../settings.py" line="87"/>
        <source>Romanian</source>
        <translation>Romanian</translation>
    </message>
    <message>
        <location filename="../settings.py" line="88"/>
        <source>Russian</source>
        <translation>Russian</translation>
    </message>
    <message>
        <location filename="../settings.py" line="89"/>
        <source>Slovak</source>
        <translation>Slovak</translation>
    </message>
    <message>
        <location filename="../settings.py" line="90"/>
        <source>Swedish</source>
        <translation>Swedish</translation>
    </message>
    <message>
        <location filename="../settings.py" line="91"/>
        <source>Turkish</source>
        <translation>Turkish</translation>
    </message>
    <message>
        <location filename="../settings.py" line="92"/>
        <source>Ukrainian</source>
        <translation>Ukrainian</translation>
    </message>
    <message>
        <location filename="../settings.py" line="93"/>
        <source>Chinese Traditional</source>
        <translation>繁体中文</translation>
    </message>
    <message>
        <location filename="../settings.py" line="94"/>
        <source>Chinese Simplified</source>
        <translation>简体中文</translation>
    </message>
    <message>
        <location filename="../settings.py" line="113"/>
        <source>Temperature unit</source>
        <translation>温度单位</translation>
    </message>
    <message>
        <location filename="../settings.py" line="189"/>
        <source>Update interval</source>
        <translation>更新间隔</translation>
    </message>
    <message>
        <location filename="../settings.py" line="190"/>
        <source>minutes</source>
        <translation>分钟</translation>
    </message>
    <message>
        <location filename="../settings.py" line="213"/>
        <source>Launch at startup</source>
        <translation>在开机时启动</translation>
    </message>
    <message>
        <location filename="../settings.py" line="221"/>
        <source>Font colour in the tray</source>
        <translation>托盘中的字体颜色</translation>
    </message>
    <message>
        <location filename="../settings.py" line="227"/>
        <source>Reset</source>
        <translation>重置</translation>
    </message>
    <message>
        <location filename="../settings.py" line="228"/>
        <source>Reset font colour to system default</source>
        <translation>将字体颜色重置为系统默认值</translation>
    </message>
    <message>
        <location filename="../settings.py" line="232"/>
        <source>Notification on weather update</source>
        <translation>天气更新通知</translation>
    </message>
    <message>
        <location filename="../settings.py" line="566"/>
        <source>Meteo-qt Configuration</source>
        <translation>Meteo-qt 配置</translation>
    </message>
</context>
<context>
    <name>Moderate UV recommended protection</name>
    <message>
        <location filename="../conditions.py" line="165"/>
        <source>Take precautions, such as covering up, if you will be
                outside.&lt;br/&gt;Stay in shade near midday
                when the sun is strongest.</source>
        <comment>Moderate https://en.wikipedia.org/wiki/Ultraviolet_index</comment>
        <translation>采取预防措施，如掩盖，如果你将
当太阳最强的时候。
&lt;br/&gt;呆在中午附近的阴凉处</translation>
    </message>
</context>
<context>
    <name>Option for logging level</name>
    <message>
        <location filename="../settings.py" line="489"/>
        <source>Logging level</source>
        <comment>Settings window</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Option to choose the default wind speed unit</name>
    <message>
        <location filename="../settings.py" line="136"/>
        <source>Default</source>
        <comment>Settings diaogue</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Option to choose wind speed unit</name>
    <message>
        <location filename="../settings.py" line="141"/>
        <source>Beaufort</source>
        <comment>Settings dialogue</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.py" line="146"/>
        <source>Km/h</source>
        <comment>Settings dialogue</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Precipitation type</name>
    <message>
        <location filename="../conditions.py" line="101"/>
        <source>no</source>
        <comment>Weather overview dialogue</comment>
        <translation>无</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="103"/>
        <source>rain</source>
        <comment>Weather overview dialogue</comment>
        <translation>雨</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="106"/>
        <source>snow</source>
        <comment>Weather overview dialogue</comment>
        <translation>雪</translation>
    </message>
</context>
<context>
    <name>Precipitation type (no/rain/snow)</name>
    <message>
        <location filename="../meteo_qt.py" line="430"/>
        <source>Precipitation</source>
        <comment>Weather overview dialogue</comment>
        <translation>霜</translation>
    </message>
</context>
<context>
    <name>Proxy password authentification</name>
    <message>
        <location filename="../proxydlg.py" line="68"/>
        <source>Password:</source>
        <comment>Proxy configuration dialogue</comment>
        <translation>密码:</translation>
    </message>
</context>
<context>
    <name>Proxy username authentification</name>
    <message>
        <location filename="../proxydlg.py" line="64"/>
        <source>User ID:</source>
        <comment>Proxy configuration dialogue</comment>
        <translation>用户帐号:</translation>
    </message>
</context>
<context>
    <name>Search by geolocalisation button tooltip</name>
    <message>
        <location filename="../searchcity.py" line="57"/>
        <source>Find my location</source>
        <comment>Automatic search of my place</comment>
        <translation>查找我的位置</translation>
    </message>
</context>
<context>
    <name>Search city</name>
    <message>
        <location filename="../searchcity.py" line="180"/>
        <source>N/A</source>
        <comment>Inserted in search field when the automaticgeolocalisation is not available</comment>
        <translation>暂时不可用</translation>
    </message>
</context>
<context>
    <name>Search city button Tooltip</name>
    <message>
        <location filename="../searchcity.py" line="44"/>
        <source>Search city</source>
        <comment>Search for the given place</comment>
        <translation>查找城市</translation>
    </message>
</context>
<context>
    <name>Search city dialogue</name>
    <message>
        <location filename="../searchcity.py" line="65"/>
        <source>Start typing the city or the ID or the geographic coordinates &quot;latitude, longitude&quot;</source>
        <comment>Default message in the search field</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchCity</name>
    <message>
        <location filename="../searchcity.py" line="33"/>
        <source>Searching...</source>
        <translation>查找中...</translation>
    </message>
    <message>
        <location filename="../searchcity.py" line="90"/>
        <source>&amp;Ok</source>
        <translation>&amp;好的</translation>
    </message>
    <message>
        <location filename="../searchcity.py" line="92"/>
        <source>&amp;Cancel</source>
        <translation>&amp;取消</translation>
    </message>
    <message>
        <location filename="../searchcity.py" line="286"/>
        <source>No results</source>
        <translation>无结果</translation>
    </message>
    <message>
        <location filename="../searchcity.py" line="288"/>
        <source>Found {0} city</source>
        <translation>发现 {0} 个城市</translation>
    </message>
    <message>
        <location filename="../searchcity.py" line="290"/>
        <source>Found {0} cities</source>
        <translation>发现 {0} 个城市</translation>
    </message>
</context>
<context>
    <name>SearchCity window</name>
    <message>
        <location filename="../searchcity.py" line="225"/>
        <source>Please type more than three characters</source>
        <comment>Message in the statusbar</comment>
        <translation>请输入3个以上字符</translation>
    </message>
</context>
<context>
    <name>Settings dialogue</name>
    <message>
        <location filename="../settings.py" line="249"/>
        <source>Icon &amp; temperature</source>
        <comment>Setting to choose the type of the icon on the tray</comment>
        <translation>图标&amp;温度</translation>
    </message>
    <message>
        <location filename="../settings.py" line="254"/>
        <source>Icon</source>
        <comment>Setting to choose the type of the icon on the tray</comment>
        <translation>图标</translation>
    </message>
    <message>
        <location filename="../settings.py" line="259"/>
        <source>Temperature</source>
        <comment>Setting to choose the type of the icon on the tray</comment>
        <translation>温度</translation>
    </message>
    <message>
        <location filename="../settings.py" line="240"/>
        <source>System tray icon</source>
        <comment>Setting to choose the type of the icon on the tray(only icon only text, icon&amp;text</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.py" line="264"/>
        <source>Icon &amp; Feels like temperature</source>
        <comment>Setting to choose the type of the icon on the tray</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.py" line="269"/>
        <source>Feels like temperature</source>
        <comment>Setting to choose the type of the icon on the tray</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.py" line="380"/>
        <source>Toggle tray icon interval</source>
        <comment>Label for the option of the checkbox to activate the toggle of the tray icon and temperature</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.py" line="394"/>
        <source>seconds. Set to 0 to deactivate</source>
        <comment>Label after the spinbox to choose the interval to toggle the tray icon and temperature</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.py" line="293"/>
        <source>System default</source>
        <comment>ComboBox to choose the system default icons theme</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.py" line="299"/>
        <source>Icons theme</source>
        <comment>Tooltip of the ComboBox to choose the icons theme</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.py" line="410"/>
        <source>Temperature font in system tray</source>
        <comment>Setting for the font size of the temperature in the tray icon</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.py" line="334"/>
        <source>Tray icon size and text position</source>
        <comment>This option concernes 2 dropdown liststo define the size to initialize the tray iconand the position of the temperature text in the icon</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.py" line="343"/>
        <source>Changing this setting you can improve the displaying of the temperature in the tray icon</source>
        <comment>ToolTip of the label &quot;Tray icon size and text position&quot;</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.py" line="352"/>
        <source>Tray icon initialization size (default size: 64x64)</source>
        <comment>Tooltip of the drowndrop list with icon sizes</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.py" line="371"/>
        <source>Temperature position in the icon (vertically) (default value: -12)</source>
        <comment>ToolTip of the widget (a spinbox) to define the position of the temperature paint in the tray icon</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.py" line="465"/>
        <source>It is suggested to use a personal key.&lt;br/&gt;If someone hijacks the default meteo-qt key you will not be able to get the weather data (error 401 unauthorized)</source>
        <comment>Tooltip of the api key text field</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Status bar message</name>
    <message>
        <location filename="../citylistdlg.py" line="95"/>
        <source>The city already exists in the list</source>
        <comment>Cities list dialogue</comment>
        <translation>该城市已经存在于该列表中</translation>
    </message>
    <message>
        <location filename="../citylistdlg.py" line="106"/>
        <source>Toggle cities with mouse scroll on the weather window</source>
        <comment>Cities list dialogue</comment>
        <translation>在天气窗口上使用鼠标滚动切换城市</translation>
    </message>
</context>
<context>
    <name>Status message</name>
    <message>
        <location filename="../searchcity.py" line="116"/>
        <source>Click on &quot;Find my Location&quot; button for automatic geolocation</source>
        <comment>City search dialogue</comment>
        <translation>点击“查找我的位置”按钮进行自动地理定位</translation>
    </message>
    <message>
        <location filename="../searchcity.py" line="126"/>
        <source>Put the city&apos;s name, comma, 2-letter country code (ex: London, GB)</source>
        <comment>City search dialogue</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>System tray notification</name>
    <message>
        <location filename="../meteo_qt.py" line="2516"/>
        <source>The application has to be restarted to apply the language setting</source>
        <translation>必须重新启动应用程序才能应用语言设置</translation>
    </message>
</context>
<context>
    <name>SystemTrayIcon</name>
    <message>
        <location filename="../meteo_qt.py" line="127"/>
        <source>Cities</source>
        <translation>城市</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="140"/>
        <source>&amp;Temporary city</source>
        <translation>&amp;临时城市</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="160"/>
        <source>&amp;Settings</source>
        <translation>&amp;设置</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="161"/>
        <source>&amp;About</source>
        <translation>&amp;关于</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="162"/>
        <source>Exit</source>
        <translation>退出</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="180"/>
        <source>Searching weather data...</source>
        <translation>正在查找天气数据...</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="1971"/>
        <source>Empty list</source>
        <translation>空的列表</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="1990"/>
        <source>No city configured</source>
        <translation>没有配置城市</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="2004"/>
        <source>No city has been configured yet.</source>
        <translation>尚未配置任何城市。</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="2004"/>
        <source>Right click on the icon and click on Settings.</source>
        <translation>右键单击图标，然后单击“设置”。</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="2584"/>
        <source>Fetching weather data...</source>
        <translation>获取天气数据......</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="2600"/>
        <source>&lt;b&gt;meteo-qt&lt;/b&gt; v{0}
            &lt;br/&gt;License: GPLv3
            &lt;br/&gt;Python {1} - Qt {2} - PyQt {3} on {4}</source>
        <translation>&lt;b&gt;meteo-qt&lt;/b&gt; v{0}
            &lt;br/&gt;许可证: GPLv3
            &lt;br/&gt;Python {1} - Qt {2} - PyQt {3} on {4}</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="201"/>
        <source>Mon</source>
        <translation>周一</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="202"/>
        <source>Tue</source>
        <translation>周二</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="203"/>
        <source>Wed</source>
        <translation>周三</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="204"/>
        <source>Thu</source>
        <translation>周四</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="205"/>
        <source>Fri</source>
        <translation>周五</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="206"/>
        <source>Sat</source>
        <translation>周六</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="207"/>
        <source>Sun</source>
        <translation>周日</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="577"/>
        <source>Weather status</source>
        <translation>天气状况</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="1445"/>
        <source>Min Max Temperature of the day</source>
        <translation>当天最低最高温度</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="2589"/>
        <source>&lt;p&gt;Author: Dimitrios Glentadakis
            &lt;a href=&quot;mailto:dglent@free.fr&quot;&gt;dglent@free.fr&lt;/a&gt;
            &lt;p&gt;A simple application showing the weather status
            information on the system tray.
            &lt;p&gt;Website: &lt;a href=&quot;https://github.com/dglent/meteo-qt&quot;&gt;
            https://github.com/dglent/meteo-qt&lt;/a&gt;
            &lt;br/&gt;Data source: &lt;a href=&quot;http://openweathermap.org/&quot;&gt;
            OpenWeatherMap&lt;/a&gt;.
            &lt;br/&gt;This software uses icons from the
            &lt;a href=&quot;http://www.kde.org/&quot;&gt;Oxygen Project&lt;/a&gt;.
            &lt;p&gt;To translate meteo-qt in your language or contribute to
            current translations, you can use the
            &lt;a href=&quot;https://www.transifex.com/projects/p/meteo-qt/&quot;&gt;
            Transifex&lt;/a&gt; platform.
            &lt;p&gt;If you want to report a dysfunction or a suggestion,
            feel free to open an issue in
            &lt;a href=&quot;https://github.com/dglent/meteo-qt/issues&quot;&gt;
            github&lt;/a&gt;.</source>
        <translation type="obsolete">&lt;p&gt;作者: Dimitrios Glentadakis
            &lt;a href=&quot;mailto:dglent@free.fr&quot;&gt;dglent@free.fr&lt;/a&gt;
            &lt;p&gt;系统托盘上的信息
             显示天气状况的简单应用程序。
            &lt;p&gt;网站: &lt;a href=&quot;https://github.com/dglent/meteo-qt&quot;&gt;
            https://github.com/dglent/meteo-qt&lt;/a&gt;
            &lt;br/&gt;数据来源: &lt;a href=&quot;http://openweathermap.org/&quot;&gt;
            OpenWeatherMap&lt;/a&gt;.
            &lt;br/&gt;软件图标来自
            &lt;a href=&quot;http://www.kde.org/&quot;&gt;Oxygen Project&lt;/a&gt;.
            &lt;p&gt;o翻译你的语言meteo-qt或贡献当前的翻译，
              你可以使用
            &lt;a href=&quot;https://www.transifex.com/projects/p/meteo-qt/&quot;&gt;
            Transifex&lt;/a&gt; 平台.
            &lt;p&gt;如果您想报告功能障碍或建议，
            请随时打开
            &lt;a href=&quot;https://github.com/dglent/meteo-qt/issues&quot;&gt;
            github&lt;/a&gt;.</translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="2609"/>
        <source>&lt;p&gt;Author: Dimitrios Glentadakis
            &lt;a href=&quot;mailto:dglent@free.fr&quot;&gt;dglent@free.fr&lt;/a&gt;
            &lt;p&gt;A simple application showing the weather status
            information on the system tray.
            &lt;p&gt;Website: &lt;a href=&quot;https://github.com/dglent/meteo-qt&quot;&gt;
            https://github.com/dglent/meteo-qt&lt;/a&gt;
            &lt;br/&gt;Data source: &lt;a href=&quot;http://openweathermap.org/&quot;&gt;
            OpenWeatherMap&lt;/a&gt;.
            &lt;br/&gt;This software uses icons from the
            &lt;a href=&quot;http://www.kde.org/&quot;&gt;Oxygen Project&lt;/a&gt;.
            &lt;p&gt;To translate meteo-qt in your language or contribute to
            current translations, you can use the
            &lt;a href=&quot;https://translate.lxqt-project.org/projects/dglent/meteo-qt/&quot;&gt;
            Weblate&lt;/a&gt; platform.
            &lt;p&gt;If you want to report a dysfunction or a suggestion,
            feel free to open an issue in
            &lt;a href=&quot;https://github.com/dglent/meteo-qt/issues&quot;&gt;
            github&lt;/a&gt;.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>The Feels Like Temperature</name>
    <message>
        <location filename="../meteo_qt.py" line="181"/>
        <source>Feels like</source>
        <comment>Weather info window</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>The air quality index is not available</name>
    <message>
        <location filename="../meteo_qt.py" line="483"/>
        <source>Unavailable</source>
        <comment>The value in the weather info dialogue</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>The key that user can generate in his OpenWeatherMap profile</name>
    <message>
        <location filename="../settings.py" line="448"/>
        <source>OpenWeatherMap key</source>
        <comment>Settings dialogue</comment>
        <translation>OpenWeatherMap 密钥</translation>
    </message>
</context>
<context>
    <name>Tooltip</name>
    <message>
        <location filename="../settings.py" line="58"/>
        <source>The application has to be restared to apply the language setting</source>
        <comment>Settings dialogue</comment>
        <translation>必须重新启动应用程序才能应用语言设置</translation>
    </message>
</context>
<context>
    <name>Tooltip forcast of the day</name>
    <message>
        <location filename="../meteo_qt.py" line="209"/>
        <source>Probability of precipitation</source>
        <comment>Weather info window</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Tooltip of UV label</name>
    <message>
        <location filename="../meteo_qt.py" line="525"/>
        <source>The ultraviolet index at 12 PM</source>
        <comment>Label in weather info dialogue</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Tooltip on weather icon on 6 days forecast</name>
    <message>
        <location filename="../meteo_qt.py" line="1121"/>
        <source>Day</source>
        <comment>Weather information window</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="1126"/>
        <source>Morning</source>
        <comment>Weather information window</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="1131"/>
        <source>Evening</source>
        <comment>Weather information window</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="1136"/>
        <source>Night</source>
        <comment>Weather information window</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Tootltip forcast of the day</name>
    <message>
        <location filename="../meteo_qt.py" line="1733"/>
        <source>Pressure</source>
        <comment>Weather info window</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../meteo_qt.py" line="1738"/>
        <source>Humidity</source>
        <comment>Weather info window</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Tray context menu</name>
    <message>
        <location filename="../meteo_qt.py" line="130"/>
        <source>Toggle Window</source>
        <comment>Open/closes the application window</comment>
        <translation>切换窗口</translation>
    </message>
</context>
<context>
    <name>Tray icon</name>
    <message>
        <location filename="../meteo_qt.py" line="2112"/>
        <source>Searching for weather data...</source>
        <comment>Tooltip (when mouse over the icon</comment>
        <translation>正在查找天气数据...</translation>
    </message>
</context>
<context>
    <name>Tray notification popup</name>
    <message>
        <location filename="../meteo_qt.py" line="68"/>
        <source>&lt;b&gt;Tomorrow:&lt;/b&gt;</source>
        <comment>Title for the weather conditions</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UV risk</name>
    <message>
        <location filename="../conditions.py" line="146"/>
        <source>Low</source>
        <translation>低</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="148"/>
        <source>Moderate</source>
        <translation>中</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="151"/>
        <source>High</source>
        <translation>高</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="153"/>
        <source>Very high</source>
        <translation>非常高</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="155"/>
        <source>Extreme</source>
        <translation>极端</translation>
    </message>
</context>
<context>
    <name>Ultraviolet index</name>
    <message>
        <location filename="../meteo_qt.py" line="516"/>
        <source>UV</source>
        <comment>Label in weather info dialogue</comment>
        <translation>紫外线</translation>
    </message>
</context>
<context>
    <name>Ultraviolet index waiting text label</name>
    <message>
        <location filename="../meteo_qt.py" line="786"/>
        <source>Fetching...</source>
        <comment>Weather info dialogue</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Unit displayed after the wind speed value and before
                the wind description (keep the spaces before and after)</name>
    <message>
        <location filename="../meteo_qt.py" line="661"/>
        <source> km/h </source>
        <comment>Weather Infos panel</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Very high UV recommended protection</name>
    <message>
        <location filename="../conditions.py" line="177"/>
        <source>Wear SPF 30+ sunscreen, a shirt, sunglasses, and a
                wide-brimmed hat.&lt;br/&gt;Do not stay in the sun for too long.</source>
        <comment>Very high https://en.wikipedia.org/wiki/Ultraviolet_index</comment>
        <translation>穿SPF 30防晒霜，衬衫，太阳镜和
               宽边帽. &lt;br/&gt;不要在太阳下呆太久。</translation>
    </message>
</context>
<context>
    <name>Visibility (distance) label</name>
    <message>
        <location filename="../meteo_qt.py" line="397"/>
        <source>Visibility</source>
        <comment>Weather overview dialogue</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Warning message after pressing OK</name>
    <message>
        <location filename="../settings.py" line="560"/>
        <source>Please add a city</source>
        <comment>Settings dialogue</comment>
        <translation>请添加一个城市</translation>
    </message>
</context>
<context>
    <name>Warning message after pressing Ok</name>
    <message>
        <location filename="../settings.py" line="555"/>
        <source>Please enter your OpenWeatherMap key</source>
        <comment>Settings dialogue</comment>
        <translation>请输入您的OpenWeatherMap密钥</translation>
    </message>
</context>
<context>
    <name>Warning message in dialog status bar</name>
    <message>
        <location filename="../citytranslate.py" line="55"/>
        <source>The city already exist</source>
        <comment>City translation</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WeatherConditions</name>
    <message>
        <location filename="../conditions.py" line="8"/>
        <source>thunderstorm with light rain</source>
        <translation>小雨伴有雷暴</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="9"/>
        <source>thunderstorm with rain</source>
        <translation>中雨伴有雷暴</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="10"/>
        <source>thunderstorm with heavy rain</source>
        <translation>大雨伴有雷暴</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="11"/>
        <source>light thunderstorm</source>
        <translation>小雷暴</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="12"/>
        <source>thunderstorm</source>
        <translation>雷暴</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="13"/>
        <source>heavy thunderstorm</source>
        <translation>强雷暴</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="14"/>
        <source>ragged thunderstorm</source>
        <translation>局部雷暴</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="15"/>
        <source>thunderstorm with light drizzle</source>
        <translation>小毛毛雨伴有雷暴</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="16"/>
        <source>thunderstorm with drizzle</source>
        <translation>毛毛雨伴有雷暴</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="17"/>
        <source>thunderstorm with heavy drizzle</source>
        <translation>强毛毛雨伴有雷暴</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="18"/>
        <source>light intensity drizzle</source>
        <translation>小毛毛雨</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="19"/>
        <source>drizzle</source>
        <translation>毛毛雨</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="20"/>
        <source>heavy intensity drizzle</source>
        <translation>强毛毛雨</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="21"/>
        <source>light intensity drizzle rain</source>
        <translation>小毛毛雨转雨</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="22"/>
        <source>drizzle rain</source>
        <translation>毛毛雨转雨</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="23"/>
        <source>heavy intensity drizzle rain</source>
        <translation>强毛毛雨转雨</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="24"/>
        <source>shower rain and drizzle</source>
        <translation>阵雨及毛毛雨</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="25"/>
        <source>heavy shower rain and drizzle</source>
        <translation>强阵雨及毛毛雨</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="26"/>
        <source>shower drizzle</source>
        <translation>阵毛毛雨</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="27"/>
        <source>light rain</source>
        <translation>小雨</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="28"/>
        <source>moderate rain</source>
        <translation>中雨</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="29"/>
        <source>heavy intensity rain</source>
        <translation>大雨</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="30"/>
        <source>very heavy rain</source>
        <translation>暴雨</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="31"/>
        <source>extreme rain</source>
        <translation>大暴雨</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="32"/>
        <source>freezing rain</source>
        <translation>冻雨</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="33"/>
        <source>light intensity shower rain</source>
        <translation>小阵雨</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="34"/>
        <source>shower rain</source>
        <translation>阵雨</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="35"/>
        <source>heavy intensity shower rain</source>
        <translation>强阵雨</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="36"/>
        <source>ragged shower rain</source>
        <translation>局部阵雨</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="37"/>
        <source>light snow</source>
        <translation>小雪</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="38"/>
        <source>snow</source>
        <translation>雪</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="39"/>
        <source>heavy snow</source>
        <translation>大雪</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="40"/>
        <source>sleet</source>
        <translation>冰雹</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="41"/>
        <source>shower sleet</source>
        <translation>阵冰雹</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="42"/>
        <source>light rain and snow</source>
        <translation>小雨夹雪</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="43"/>
        <source>rain and snow</source>
        <translation>雨夹雪</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="44"/>
        <source>light shower snow</source>
        <translation>小阵雪</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="45"/>
        <source>shower snow</source>
        <translation>阵雪</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="46"/>
        <source>heavy shower snow</source>
        <translation>强阵雪</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="47"/>
        <source>mist</source>
        <translation>薄雾</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="48"/>
        <source>smoke</source>
        <translation>烟</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="49"/>
        <source>haze</source>
        <translation>霾</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="50"/>
        <source>sand, dust whirls</source>
        <translation>沙子，灰尘旋转</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="51"/>
        <source>fog</source>
        <translation>雾</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="52"/>
        <source>sand</source>
        <translation>扬沙</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="53"/>
        <source>dust</source>
        <translation>浮尘</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="54"/>
        <source>volcanic ash</source>
        <translation>火山灰</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="55"/>
        <source>squalls</source>
        <translation>狂风</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="62"/>
        <source>tornado</source>
        <translation>龙卷风</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="57"/>
        <source>clear sky</source>
        <translation>晴朗的天空</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="58"/>
        <source>few clouds</source>
        <translation>少云</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="59"/>
        <source>scattered clouds</source>
        <translation>疏云</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="60"/>
        <source>broken clouds</source>
        <translation>碎云</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="61"/>
        <source>overcast clouds</source>
        <translation>阴天</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="63"/>
        <source>tropical storm</source>
        <translation>热带风暴</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="80"/>
        <source>hurricane</source>
        <translation>飓风</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="65"/>
        <source>cold</source>
        <translation>冷</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="66"/>
        <source>hot</source>
        <translation>热</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="67"/>
        <source>windy</source>
        <translation>有风</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="68"/>
        <source>hail</source>
        <translation>冰雹</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="69"/>
        <source>calm</source>
        <translation>平静</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="70"/>
        <source>light breeze</source>
        <translation>微风</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="71"/>
        <source>gentle breeze</source>
        <translation>轻风</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="72"/>
        <source>moderate breeze</source>
        <translation>缓风</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="73"/>
        <source>fresh breeze</source>
        <translation>清风</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="74"/>
        <source>strong breeze</source>
        <translation>强风</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="75"/>
        <source>high wind, near gale</source>
        <translation>大风</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="76"/>
        <source>gale</source>
        <translation>超大风</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="77"/>
        <source>severe gale</source>
        <translation>巨风</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="78"/>
        <source>storm</source>
        <translation>暴风</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="79"/>
        <source>violent storm</source>
        <translation>大暴风</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="111"/>
        <source>North</source>
        <translation>北</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="112"/>
        <source>NorthEast</source>
        <translation>东北</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="113"/>
        <source>North-northeast</source>
        <translation>东北偏北</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="114"/>
        <source>NorthWest</source>
        <translation>西北</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="115"/>
        <source>North-northwest</source>
        <translation>西北偏北</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="116"/>
        <source>South</source>
        <translation>南</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="117"/>
        <source>SouthEast</source>
        <translation>东南</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="118"/>
        <source>South-southeast</source>
        <translation>东南偏南</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="119"/>
        <source>SouthWest</source>
        <translation>西南</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="120"/>
        <source>South-southwest</source>
        <translation>西南偏南</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="121"/>
        <source>East</source>
        <translation>东</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="122"/>
        <source>East-southeast</source>
        <translation>东南偏东</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="123"/>
        <source>East-northeast</source>
        <translation>东北偏东</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="124"/>
        <source>West</source>
        <translation>西</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="125"/>
        <source>West-southwest</source>
        <translation>西南偏西</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="126"/>
        <source>West-northwest</source>
        <translation>西北偏西</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="128"/>
        <source>N</source>
        <translation>N</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="129"/>
        <source>NE</source>
        <translation>NE</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="130"/>
        <source>NNE</source>
        <translation>NNE</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="131"/>
        <source>NW</source>
        <translation>NW</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="132"/>
        <source>NNW</source>
        <translation>NNW</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="133"/>
        <source>S</source>
        <translation>S</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="134"/>
        <source>SE</source>
        <translation>SE</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="135"/>
        <source>SSE</source>
        <translation>SSE</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="136"/>
        <source>SW</source>
        <translation>SW</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="137"/>
        <source>SSW</source>
        <translation>SSW</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="138"/>
        <source>E</source>
        <translation>E</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="139"/>
        <source>ESE</source>
        <translation>ESE</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="140"/>
        <source>ENE</source>
        <translation>ENE</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="141"/>
        <source>W</source>
        <translation>W</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="142"/>
        <source>WSW</source>
        <translation>WSW</translation>
    </message>
    <message>
        <location filename="../conditions.py" line="143"/>
        <source>WNW</source>
        <translation>WNW</translation>
    </message>
</context>
<context>
    <name>Window title</name>
    <message>
        <location filename="../citylistdlg.py" line="67"/>
        <source>Cities</source>
        <comment>Cities list dialogue</comment>
        <translation>城市</translation>
    </message>
    <message>
        <location filename="../citytranslate.py" line="38"/>
        <source>City translation</source>
        <comment>City translation dialogue</comment>
        <translation>城市翻译</translation>
    </message>
    <message>
        <location filename="../searchcity.py" line="109"/>
        <source>Find a city</source>
        <comment>City search dialogue</comment>
        <translation>查找城市</translation>
    </message>
</context>
<context>
    <name>WorkThread</name>
    <message>
        <location filename="../searchcity.py" line="354"/>
        <source>Data error, please try again later
or modify the name of the city</source>
        <translation>数据错误，请稍后再试
或修改城市名称</translation>
    </message>
    <message>
        <location filename="../searchcity.py" line="390"/>
        <source>Please wait, searching...</source>
        <translation>稍等,正在查找...</translation>
    </message>
    <message>
        <location filename="../searchcity.py" line="398"/>
        <source>Error: </source>
        <translation>错误:</translation>
    </message>
    <message>
        <location filename="../searchcity.py" line="398"/>
        <source>
Try again later</source>
        <translation>
稍后再试</translation>
    </message>
</context>
</TS>
